@@ -1,10 +1,12 @@
 from tendenci.apps.contacts.models import Contact
 from django import forms
-from captcha.fields import CaptchaField
+#from captcha.fields import CaptchaField
 from django.utils.translation import ugettext_lazy as _ 
 
 from tendenci.core.base.fields import EmailVerificationField
 
+from simplemathcaptcha.fields import MathCaptchaField
+
 class ContactForm(forms.ModelForm):
     class Meta:
         model = Contact
@@ -35,4 +37,4 @@ class SubmitContactForm(forms.Form):
     url = forms.URLField(label=_('URL'), max_length=200, required=False)
 
     message = forms.CharField(widget=forms.Textarea)
-    captcha = CaptchaField()
+    captcha = MathCaptchaField()
